Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/netbsd-8]: src/sys/dev/mii Pull up following revision(s) (requested by m...



details:   https://anonhg.NetBSD.org/src/rev/47f5ac8f32fc
branches:  netbsd-8
changeset: 447082:47f5ac8f32fc
user:      martin <martin%NetBSD.org@localhost>
date:      Sun Dec 30 12:16:16 2018 +0000

description:
Pull up following revision(s) (requested by msaitoh in ticket #1149):

        sys/dev/mii/mii_physubr.c: revision 1.81
        sys/dev/mii/mii_physubr.c: revision 1.82

  KNF in comment. No functional change.

 -

  802.3 22.2.4.1.1 "Reset" says The reset shall be completed in 0.5s, so change
the value from 100ms to 500ms.

diffstat:

 sys/dev/mii/mii_physubr.c |  14 +++++++-------
 1 files changed, 7 insertions(+), 7 deletions(-)

diffs (42 lines):

diff -r d9dd3321cff1 -r 47f5ac8f32fc sys/dev/mii/mii_physubr.c
--- a/sys/dev/mii/mii_physubr.c Thu Dec 27 12:21:08 2018 +0000
+++ b/sys/dev/mii/mii_physubr.c Sun Dec 30 12:16:16 2018 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mii_physubr.c,v 1.80 2013/06/20 13:56:29 roy Exp $     */
+/*     $NetBSD: mii_physubr.c,v 1.80.26.1 2018/12/30 12:16:16 martin Exp $     */
 
 /*-
  * Copyright (c) 1998, 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -35,7 +35,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mii_physubr.c,v 1.80 2013/06/20 13:56:29 roy Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mii_physubr.c,v 1.80.26.1 2018/12/30 12:16:16 martin Exp $");
 
 #include <sys/param.h>
 #include <sys/device.h>
@@ -237,9 +237,9 @@
                        }
 
                        /*
-                        *for 1000-base-T, autonegotiation mus be enabled, but 
-                        *if we're not set to auto, only advertise
-                        *1000-base-T with the link partner.
+                        *  For 1000-base-T, autonegotiation must be enabled,
+                        * but if we're not set to auto, only advertise
+                        * 1000-base-T with the link partner.
                         */
                        if (IFM_SUBTYPE(ife->ifm_media) == IFM_1000_T) {
                                anar &= ~(ANAR_T4|ANAR_TX_FD|ANAR_TX|ANAR_10_FD|ANAR_10);
@@ -387,8 +387,8 @@
                reg = BMCR_RESET | BMCR_ISO;
        PHY_WRITE(sc, MII_BMCR, reg);
 
-       /* Wait another 100ms for it to complete. */
-       for (i = 0; i < 100; i++) {
+       /* Wait another 500ms for it to complete. */
+       for (i = 0; i < 500; i++) {
                reg = PHY_READ(sc, MII_BMCR);
                if ((reg & BMCR_RESET) == 0)
                        break;



Home | Main Index | Thread Index | Old Index